==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/modules/admin/messages/hu/space.php <==
<?php
return array (
  '<strong>Manage</strong> spaces' => 'Közösségek <strong>kezelése</strong>',
  'Add new space' => 'Új közösség hozzáadása',
  'Change owner' => 'Tulajdonos megváltoztatása',
  'Default Content Visiblity' => 'Tartalom láthatóságának alapértelmezése',
  'Default Join Policy' => 'Csatlakozási irányelv alapértelmezése',
  'Default Permissions' => 'Alapértelmezett jogosultságok',
  'Default Space Permissions' => 'Alapértelmezett területi jogosultságok',
  'Default Space(s)' => 'Alapértelmezett hely(ek)',
  'Default Visibility' => 'Láthatóság alapértelmezése',
  'Default space' => 'Alapértelmezett közösség',
  'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => 'Itt meghatározhatja a helyek alapértelmezett engedélyeit. Ezek a beállítások felülírják a konfigurációs fájl alapértelmezett jogosultságait, és minden egyes hely felülírható.',
  'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => 'Itt adhatsz meg alapértelmezett beállításokat az új közösségekhez. Ezek a beállítások minden egyes közösségnél felülírhatók.',
  'Invalid space' => 'Érvénytelen közösség',
  'Manage members' => 'Tagok kezelése',
  'Manage modules' => 'Modulok kezelése',
  'Open space' => 'Nyitott közösség',
  'Overview' => 'Áttekintés',
  'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => 'Az engedélyek különböző felhasználói szerepkörökhöz vannak rendelve. Alapértelmezett engedély szerkesztéséhez válassza ki a szerkeszteni kívánt felhasználói szerepkört, és módosítsa a megadott engedély értékét a legördülő menüben.',
  'Search by name, description, id or owner.' => 'Keresés név, leírás, azonosító vagy tulajdonos szerint.',
  'Settings' => 'Beállítások',
  'Space Settings' => 'Közösség beállításai',
  'Spaces' => 'Közösségek',
  'This overview contains a list of each space with actions to view, edit and delete spaces.' => 'Ez az áttekintés tartalmazza az egyes közösségek listáját, megtekintés, szerkesztés és törlés opciókkal.',
  'Update Space memberships also for existing members.' => 'A területi tagságok frissítése a meglévő tagok számára is.',
);

==> humhub-1.15.0-beta.1.tar.gz: humhub-1.15.0-beta.1/protected/humhub/modules/admin/messages/hu/space.php <==
<?php
return array (
  '<strong>Manage</strong> Spaces' => 'Közösségek <strong>kezelése</strong>',
  'Add new space' => 'Új közösség hozzáadása',
  'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => 'Az engedélyek különböző felhasználói szerepkörökhöz vannak rendelve. Alapértelmezett engedély szerkesztéséhez válassza ki a szerkeszteni kívánt felhasználói szerepkört, és módosítsa a megadott engedély értékét a legördülő menüben.',
  'Change owner' => 'Tulajdonos megváltoztatása',
  'Default "Hide About Page"' => 'Alapértelmezett "Névjegy oldal elrejtése"',
  'Default "Hide Activity Sidebar Widget"' => 'Alapértelmezett "Tevékenység oldalsáv widget elrejtése"',
  'Default "Hide Followers"' => 'Alapértelmezett "Követők elrejtése"',
  'Default "Hide Members"' => 'Alapértelmezett "Tagok elrejtése"',
  'Default Content Visiblity' => 'Tartalom láthatóságának alapértelmezése',
  'Default Join Policy' => 'Csatlakozási irányelv alapértelmezése',
  'Default Space Permissions' => 'Alapértelmezett területi jogosultságok',
  'Default Space(s)' => 'Alapértelmezett közösségek',
  'Default Visibility' => 'Láthatóság alapértelmezése',
  'Default homepage' => 'Alapértelmezett kezdőlap',
  'Default homepage (Non-members)' => 'Alapértelmezett kezdőlap (nem tagok)',
  'Default space' => 'Alapértelmezett közösség',
  'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => 'Itt adhatsz meg alapértelmezett beállításokat az új közösségekhez. Ezek a beállítások minden egyes közösségnél felülírhatók.',
  'Invalid space' => 'Érvénytelen közösség',
  'Manage members' => 'Tagok kezelése',
  'Manage modules' => 'Modulok kezelése',
  'Open space' => 'Nyitott közösség',
  'Overview' => 'Áttekintés',
  'Permissions' => 'Engedélyek',
  'Search by name, description, id or owner.' => 'Keresés név, leírás, azonosító vagy tulajdonos szerint.',
  'Settings' => 'Beállítások',
  'Space Settings' => 'Közösség beállításai',
  'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => 'Itt meghatározhatja a helyek alapértelmezett engedélyeit. Ezek a beállítások felülírják a konfigurációs fájl alapértelmezett jogosultságait, és minden egyes hely felülírható.',
  'This overview contains a list of each space with actions to view, edit and delete spaces.' => 'Ez az áttekintés tartalmazza az egyes közösségek listáját, megtekintés, szerkesztés és törlés opciókkal.',
  'Update Space memberships also for existing members.' => 'A területi tagságok frissítése a meglévő tagok számára is.',
);
